"""Mmlu prox group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

MMLU_PROX_TASKS = {
    "mmlu_prox": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ar_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_bn_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_de_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_en_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_es_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_fr_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_hi_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ja_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_ko_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_pt_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_sw_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_th_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_biology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_business": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_chemistry": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_computer_science": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_economics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_engineering": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_health": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_history": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_law": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_math": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_other": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_philosophy": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_physics": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
    "mmlu_prox_zh_psychology": f"{BASE_IMPORT}mmlu_pro:MMLUProExtractor",
}
